#!/usr/bin/perl

# Based heavily on Postfix.pm
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

package Libconf::Glueconf::Networking::Sshd_config;
use strict;
use Libconf qw(:helpers);;
use Libconf::Glueconf;
use Libconf::Glueconf::Generic::KeyValue;
use Libconf::Templates::Generic::KeyValue;
our @ISA = qw(Libconf::Glueconf::Generic::KeyValue);

=head1 NAME

PERL : Libconf::Glueconf::Networking::Sshd_config
C/PYTHON/RUBY : Networking/Sshd_config

=head1 DESCRIPTION

Libconf::Glueconf::Networking:Sshd_config is a template that handles the sshd_config files from ssh server.

=head1 SYNOPSIS

  $sshd_config = new Libconf::Glueconf::Networking::Sshd_config({ filename => '/etc/ssh/sshd_config' });
  $sshd_config->{Protocol} = '1';
  $sshd_config->write_conf();

=head1 CONSTRUCTOR

=over

=item B<new($options)>

creates the template

  $sshd_config = new Libconf::Glueconf::Networking::Sshd_config({
                                                                 .. arguments .. 
                                                               })

the options are the same as in L<Libconf::Templates::Generic::KeyValue>, look
there to have the details.

=back

=head1 METHODS

See <Libconf::Glueconf> for general methods

=cut

sub new {
    my ($class, $args) = @_;

    my $libconf = new Libconf::Templates::Generic::KeyValue(add2hash_(deepcopy($args),
                                                                      {
                                                                       separator_char => '\s',
                                                                       output_separator_char => ' ',
                                                                       allow_space => 1,
								       handle_backslash => 0,
                                                                       handle_quote => 0,
                                                                       handle_multiples_lines => 0,
                                                                      }
                                                                     )
                                                           );
    $libconf->read_conf();
    $libconf->set_uniq(qw(key));
#    tie my %wrapper, 'Libconf::Glueconf::Generic::KeyValue::Wrapper', $libconf;
    tie my %wrapper, 'Libconf::Glueconf::Networking::Sshd_config::Wrapper', $libconf;
    bless \%wrapper, $class;
}

sub description { 'template for the sshd_config configuration file' }

package Libconf::Glueconf::Networking::Sshd_config::Wrapper;
use Libconf::Glueconf::Wrapper;
our @ISA = qw(Libconf::Glueconf::Generic::KeyValue::Wrapper Libconf::Glueconf::Wrapper);


1;
